User's Guide
============

Before you start diving into the details of programming systems and blocks, have
a look at the :doc:`mathematical background of dynamical systems <math>`, if you
haven't already. That theory will help you understand much better what goes on
in the system simulation.

With the maths basics out of the way, let us dive into creating system models.

.. toctree::
    :glob:
    :maxdepth: 1

    guide/*
